package edu.lawrence.invasiveandroid

import androidx.room.Dao
import androidx.room.Database
import androidx.room.Delete
import androidx.room.Entity
import androidx.room.Insert
import androidx.room.OnConflictStrategy
import androidx.room.PrimaryKey
import androidx.room.Query
import androidx.room.RoomDatabase

@Entity
data class Species(@PrimaryKey() val idspecies : Int, val name : String, val image : String)

@Entity
data class Park(@PrimaryKey() val idpark : Int = 0, val name : String, val county : String)

@Entity
data class Observation(@PrimaryKey(autoGenerate=true) val id : Int = 0, var user : Int, val park : Int, val species : Int, val comment : String, val date : String)

@Dao
interface InvasiveDao {
    @Insert(onConflict = OnConflictStrategy.REPLACE)
    suspend fun insertSpecies(species : Species)

    @Insert(onConflict = OnConflictStrategy.REPLACE)
    suspend fun insertPark(park : Park)

    @Insert(onConflict = OnConflictStrategy.REPLACE)
    suspend fun insertObservation(observation: Observation)

    @Delete
    suspend fun removeObservation(observation: Observation)

    @Query("SELECT * from species ORDER BY name")
    suspend fun loadSpecies() : List<Species>

    @Query("SELECT DISTINCT county FROM park ORDER BY county")
    suspend fun loadCounties() : List<String>

    @Query("SELECT * from park WHERE county= :county ORDER BY name")
    suspend fun loadCountyParks(county : String) : List<Park>

    @Query("SELECT * from observation")
    suspend fun loadObservations() : List<Observation>
}

@Database(entities = [Species::class,Park::class,Observation::class], version = 1)
abstract class InvasiveDatabase : RoomDatabase() {
    abstract fun invasiveDao() : InvasiveDao
}