package edu.lawrence.invasiveandroid

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.text.KeyboardActions
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalFocusManager
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.unit.dp

@Composable
fun LoginView(vm : InvasiveModel,toLanding : () -> Unit) {
    val focusManager = LocalFocusManager.current
    val name = remember { mutableStateOf("") }
    val password = remember { mutableStateOf("") }
    val realname = remember { mutableStateOf("") }
    val phone = remember { mutableStateOf("") }
    Column(horizontalAlignment = Alignment.End, verticalArrangement = Arrangement.Center, modifier = Modifier
        .padding(horizontal = 20.dp)
        .fillMaxSize()) {
        TextField(value = name.value,
            onValueChange = {newValue : String -> name.value = newValue},
            label = { Text("User Name") },
            keyboardOptions = KeyboardOptions(imeAction = ImeAction.Done),
            keyboardActions = KeyboardActions(
                onDone = { focusManager.clearFocus() })
        )
        Spacer(modifier= Modifier.height(10.dp))
        TextField(value = password.value,
            onValueChange = {newValue : String -> password.value = newValue},
            label = { Text("Password") },
            visualTransformation = PasswordVisualTransformation(),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Password, imeAction = ImeAction.Done),
            keyboardActions = KeyboardActions(
                onDone = { focusManager.clearFocus() })
        )
        Spacer(modifier= Modifier.height(10.dp))
        TextField(value = realname.value,
            onValueChange = {newValue : String -> realname.value = newValue},
            label = { Text("Real Name") },
            keyboardOptions = KeyboardOptions(imeAction = ImeAction.Done),
            keyboardActions = KeyboardActions(
                onDone = { focusManager.clearFocus() })
        )
        Spacer(modifier= Modifier.height(10.dp))
        TextField(value = phone.value,
            onValueChange = {newValue : String -> phone.value = newValue},
            label = { Text("Phone") },
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Phone, imeAction = ImeAction.Done),
            keyboardActions = KeyboardActions(
                onDone = { focusManager.clearFocus() })
        )
        Spacer(modifier= Modifier.height(20.dp))
        Row() {
            Button(onClick = {
                val user = User(username = name.value,
                    password = password.value,
                    realname = realname.value,
                    phone = phone.value)
                vm.newUser(user = user, onSuccess = toLanding)
            }) {
                Text("New User")
            }
            Spacer(modifier= Modifier.fillMaxSize(0.5F))
            Button(onClick = {vm.login(name.value,password.value,toLanding)}) {
                Text("Log In")
            }

        }
    }
}
