package edu.lawrence.invasiveandroid

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.text.KeyboardActions
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material3.Button
import androidx.compose.material3.CenterAlignedTopAppBar
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.ExposedDropdownMenuBox
import androidx.compose.material3.ExposedDropdownMenuDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalFocusManager
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.lifecycle.ViewModelProvider
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import coil.compose.AsyncImage
import edu.lawrence.invasiveandroid.ui.theme.InvasiveAndroidTheme

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        val vm = ViewModelProvider(
            this,
            ViewModelProvider.AndroidViewModelFactory.getInstance(application)
        ).get(InvasiveModel::class.java)

        setContent {
            InvasiveAndroidTheme {
                InvasiveApp(vm)
            }
        }
    }
}

@Composable
fun InvasiveApp(vm : InvasiveModel) {
    val navController = rememberNavController()
    NavHost(navController,startDestination="landing") {
        composable(route="landing") {
            LandingView(
                vm,
                toLogin = { navController.navigate("login")},
                toGallery = { navController.navigate("gallery")},
                toRecord = { navController.navigate("record")}
            )
        }
        composable(route="login") {
            LoginView(vm,toLanding = { navController.navigate("landing")})
        }
        composable(route="gallery") {
            GalleryView(vm,toLanding = { navController.navigate("landing")})
        }
        composable(route="record") {
            RecordView(vm,toLanding = { navController.navigate("landing")})
        }
    }
}

@Composable
fun LandingView(vm : InvasiveModel,toLogin : () -> Unit, toGallery : () -> Unit, toRecord: () -> Unit) {
    Column(horizontalAlignment = Alignment.CenterHorizontally, verticalArrangement = Arrangement.Center,modifier = Modifier.fillMaxSize()) {
        Button(onClick = { toGallery() }) {
            Text("Species Gallery")
        }
        Button(onClick = { toRecord() }) {
            Text("Record Observation")
        }
        Button(
            onClick = { vm.uploadObservations() },
            enabled = vm.observations.isNotEmpty() && vm.userid.value != 0
        ){
            Text("Upload Observations")
        }
        Button(
            onClick = { toLogin() },
            enabled = vm.userid.value == 0
        ) {
            Text("Log In")
        }
    }
}
