package edu.lawrence.invasiveandroid

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.text.KeyboardActions
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material3.Button
import androidx.compose.material3.CenterAlignedTopAppBar
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.ExposedDropdownMenuBox
import androidx.compose.material3.ExposedDropdownMenuDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalFocusManager
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.unit.dp

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun RecordView(vm : InvasiveModel,toLanding : () -> Unit) {
    val countiesList = remember { vm.counties }
    val parksList = remember { vm.parks }
    val speciesList = remember { vm.species }
    val comment = remember { mutableStateOf("") }
    val date = remember { mutableStateOf("") }
    val focusManager = LocalFocusManager.current
    val countiesExpanded = remember { mutableStateOf(false) }
    val selectedCounty = remember { mutableStateOf(vm.counties.value.first()) }
    val parksExpanded = remember { mutableStateOf(false) }
    val selectedPark = remember { mutableStateOf(vm.parks.value.first()) }
    val speciesExpanded = remember { mutableStateOf(false) }
    val selectedSpecies = remember { mutableStateOf(vm.species.value.first()) }

    Scaffold(
        topBar = {
            CenterAlignedTopAppBar(
                title = {
                    Text(
                        "Record Observation",
                    )
                },
                navigationIcon = {
                    IconButton(onClick = toLanding) {
                        Icon(
                            imageVector = Icons.AutoMirrored.Filled.ArrowBack,
                            contentDescription = "Back to Main"
                        )
                    }
                },
            )
        },
    ) { innerPadding ->
        Column(verticalArrangement = Arrangement.Top, horizontalAlignment = Alignment.CenterHorizontally, modifier = Modifier.fillMaxSize().padding(innerPadding)) {
            if(countiesList.value.isEmpty()) {
                Text("Loading...")
            } else {
                ExposedDropdownMenuBox(
                    expanded = countiesExpanded.value,
                    onExpandedChange = { countiesExpanded.value = it },
                ) {
                    TextField(
                        value = selectedCounty.value,
                        onValueChange = {},
                        readOnly = true,
                        trailingIcon = {
                            ExposedDropdownMenuDefaults.TrailingIcon(expanded = countiesExpanded.value)
                        },
                        label = {
                            Text("Select a county")
                        },
                        colors = ExposedDropdownMenuDefaults.textFieldColors(),
                        modifier = Modifier.menuAnchor()
                    )
                    ExposedDropdownMenu(
                        expanded = countiesExpanded.value,
                        onDismissRequest = { countiesExpanded.value = false },
                    ) {
                        countiesList.value.forEach { county ->
                            DropdownMenuItem(
                                text = {
                                    Text(
                                        county,
                                        style = MaterialTheme.typography.bodyLarge
                                    )
                                },
                                onClick = {
                                    selectedCounty.value = county
                                    countiesExpanded.value = false
                                    vm.loadParksForCounty(county = selectedCounty.value)
                                },
                                contentPadding = ExposedDropdownMenuDefaults.ItemContentPadding,
                            )
                        }
                    }
                }
                Spacer(modifier = Modifier.height(10.dp))
                ExposedDropdownMenuBox(
                    expanded = parksExpanded.value,
                    onExpandedChange = { parksExpanded.value = it },
                ) {
                    TextField(
                        value = selectedPark.value.name,
                        onValueChange = {},
                        readOnly = true,
                        trailingIcon = {
                            ExposedDropdownMenuDefaults.TrailingIcon(expanded = parksExpanded.value)
                        },
                        label = {
                            Text("Select a park")
                        },
                        colors = ExposedDropdownMenuDefaults.textFieldColors(),
                        modifier = Modifier.menuAnchor()
                    )
                    ExposedDropdownMenu(
                        expanded = parksExpanded.value,
                        onDismissRequest = { parksExpanded.value = false },
                    ) {
                        parksList.value.forEach { park ->
                            DropdownMenuItem(
                                text = {
                                    Text(
                                        park.name,
                                        style = MaterialTheme.typography.bodyLarge
                                    )
                                },
                                onClick = {
                                    selectedPark.value = park
                                    parksExpanded.value = false
                                },
                                contentPadding = ExposedDropdownMenuDefaults.ItemContentPadding,
                            )
                        }
                    }
                }
                Spacer(modifier = Modifier.height(10.dp))
                ExposedDropdownMenuBox(
                    expanded = speciesExpanded.value,
                    onExpandedChange = { speciesExpanded.value = it },
                ) {
                    TextField(
                        value = selectedSpecies.value.name,
                        onValueChange = {},
                        readOnly = true,
                        trailingIcon = {
                            ExposedDropdownMenuDefaults.TrailingIcon(expanded = speciesExpanded.value)
                        },
                        label = {
                            Text("Select a species")
                        },
                        colors = ExposedDropdownMenuDefaults.textFieldColors(),
                        modifier = Modifier.menuAnchor()
                    )
                    ExposedDropdownMenu(
                        expanded = speciesExpanded.value,
                        onDismissRequest = { speciesExpanded.value = false },
                    ) {
                        speciesList.value.forEach { species ->
                            DropdownMenuItem(
                                text = {
                                    Text(
                                        species.name,
                                        style = MaterialTheme.typography.bodyLarge
                                    )
                                },
                                onClick = {
                                    selectedSpecies.value = species
                                    speciesExpanded.value = false
                                },
                                contentPadding = ExposedDropdownMenuDefaults.ItemContentPadding,
                            )
                        }
                    }
                }
                Spacer(modifier = Modifier.height(10.dp))
                TextField(value = comment.value,
                    onValueChange = {newValue : String -> comment.value = newValue},
                    label = { Text("Enter information about your observation") },
                    maxLines = 5,
                    singleLine = false,
                    keyboardOptions = KeyboardOptions(imeAction = ImeAction.Done),
                    keyboardActions = KeyboardActions(
                        onDone = { focusManager.clearFocus() })
                )
                Spacer(modifier= Modifier.height(10.dp))
                TextField(value = date.value,
                    onValueChange = {newValue : String -> date.value = newValue},
                    label = { Text("Date of observation") },
                    placeholder = { Text("yyyy-mm-dd") },
                    keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Phone, imeAction = ImeAction.Done),
                    keyboardActions = KeyboardActions(
                        onDone = { focusManager.clearFocus() })
                )
                Spacer(modifier= Modifier.height(20.dp))
                Button(onClick = {
                    val observation = Observation(
                        user = vm.userid.value,
                        park = selectedPark.value.idpark,
                        species = selectedSpecies.value.idspecies,
                        comment = comment.value,
                        date = date.value
                    )
                    vm.addObservation(observation)
                }) {
                    Text("Record Observation")
                }

            }


        }
    }
}
